@@ -5,7 +5,7 @@
  * $Author: kou $
  * $Date: 2008-09-19 12:56:27 $
  *
- * Copyright 2005-2017 Kouhei Sutou <kou@cozmixng.org>
+ * Copyright 2005-2022 Sutou Kouhei <kou@cozmixng.org>
  * Copyright 2005 Øyvind Kolås <pippin@freedesktop.org>
  * Copyright 2004-2005 MenTaLguY <mental@rydia.com>
  *
@@ -41,6 +41,7 @@ VALUE rb_mCairo_MimeType = Qnil;
 VALUE rb_mCairo_RegionOverlap = Qnil;
 VALUE rb_mCairo_PDFOutlineFlags = Qnil;
 VALUE rb_mCairo_PDFMetadata = Qnil;
+VALUE rb_mCairo_SVGUnit = Qnil;
 
 #define CAIRO_OPERATOR_MIN CAIRO_OPERATOR_CLEAR
 #if CAIRO_CHECK_VERSION(1, 10, 0)
@@ -91,7 +92,9 @@ VALUE rb_mCairo_PDFMetadata = Qnil;
 #else
 #  define CAIRO_FORMAT_MIN CAIRO_FORMAT_ARGB32
 #endif
-#if CAIRO_CHECK_VERSION(1, 11, 4)
+#if CAIRO_CHECK_VERSION(1, 17, 2)
+#  define CAIRO_FORMAT_MAX CAIRO_FORMAT_RGBA128F
+#elif CAIRO_CHECK_VERSION(1, 11, 4)
 #  define CAIRO_FORMAT_MAX CAIRO_FORMAT_RGB30
 #else
 #  define CAIRO_FORMAT_MAX CAIRO_FORMAT_RGB16_565
@@ -110,7 +113,11 @@ VALUE rb_mCairo_PDFMetadata = Qnil;
 #define CAIRO_PS_LEVEL_MAX CAIRO_PS_LEVEL_3
 
 #define CAIRO_PDF_VERSION_MIN CAIRO_PDF_VERSION_1_4
-#define CAIRO_PDF_VERSION_MAX CAIRO_PDF_VERSION_1_5
+#if CAIRO_CHECK_VERSION(1, 17, 6)
+#  define CAIRO_PDF_VERSION_MAX CAIRO_PDF_VERSION_1_7
+#else
+#  define CAIRO_PDF_VERSION_MAX CAIRO_PDF_VERSION_1_5
+#endif
 
 #define CAIRO_TEXT_CLUSTER_FLAG_MIN 0
 #define CAIRO_TEXT_CLUSTER_FLAG_MAX CAIRO_TEXT_CLUSTER_FLAG_BACKWARD
@@ -138,6 +145,9 @@ VALUE rb_mCairo_PDFMetadata = Qnil;
 #define CAIRO_PDF_METADATA_MIN CAIRO_PDF_METADATA_TITLE
 #define CAIRO_PDF_METADATA_MAX CAIRO_PDF_METADATA_MOD_DATE
 
+#define CAIRO_SVG_UNIT_MIN CAIRO_SVG_UNIT_USER
+#define CAIRO_SVG_UNIT_MAX CAIRO_SVG_UNIT_PERCENT
+
 #define DEFINE_RVAL2ENUM(name, const_name)                      \
 cairo_ ## name ## _t                                            \
 rb_cairo_ ## name ## _from_ruby_object (VALUE rb_ ## name)      \
@@ -212,6 +222,10 @@ DEFINE_RVAL2ENUM(pdf_outline_flags, PDF_OUTLINE_FLAGS)
 DEFINE_RVAL2ENUM(pdf_metadata, PDF_METADATA)
 #endif
 
+#if CAIRO_CHECK_VERSION(1, 15, 10)
+DEFINE_RVAL2ENUM(svg_unit, SVG_UNIT)
+#endif
+
 #if defined(RB_CAIRO_PLATFORM_WIN32) && !defined(PS_LEVEL_ENUM_DEFINED)
 void
 rb_cairo_ps_level_from_ruby_object (VALUE rb_ps_level)
@@ -558,6 +572,12 @@ Init_cairo_constants (void)
   rb_define_const (rb_mCairo_Format,    "RGB30",
                    INT2FIX (CAIRO_FORMAT_RGB30));
 #endif
+#if CAIRO_CHECK_VERSION(1, 17, 2)
+  rb_define_const (rb_mCairo_Format,    "RGB96F",
+                   INT2FIX (CAIRO_FORMAT_RGB96F));
+  rb_define_const (rb_mCairo_Format,    "RGBA128F",
+                   INT2FIX (CAIRO_FORMAT_RGBA128F));
+#endif
 
 #if CAIRO_CHECK_VERSION(1, 5, 8)
   rb_define_singleton_method (rb_mCairo_Format, "stride_for_width",
@@ -628,6 +648,12 @@ Init_cairo_constants (void)
                    INT2FIX (CAIRO_PDF_VERSION_1_4));
   rb_define_const (rb_mCairo_PDFVersion, "VERSION_1_5",
                    INT2FIX (CAIRO_PDF_VERSION_1_5));
+#    if CAIRO_CHECK_VERSION(1, 17, 6)
+  rb_define_const (rb_mCairo_PDFVersion, "VERSION_1_6",
+                   INT2FIX (CAIRO_PDF_VERSION_1_6));
+  rb_define_const (rb_mCairo_PDFVersion, "VERSION_1_7",
+                   INT2FIX (CAIRO_PDF_VERSION_1_7));
+#    endif
 
   rb_define_singleton_method (rb_mCairo_PDFVersion, "list",
                               cr_pdf_get_versions, 0);
@@ -677,6 +703,16 @@ Init_cairo_constants (void)
   rb_define_const (rb_mCairo_MimeType, "JBIG2_GLOBAL_ID",
                    rb_str_new2 (CAIRO_MIME_TYPE_JBIG2_GLOBAL_ID));
 #endif
+#if CAIRO_CHECK_VERSION(1, 15, 10)
+  rb_define_const (rb_mCairo_MimeType, "CCITT_FAX",
+                   rb_str_new_cstr (CAIRO_MIME_TYPE_CCITT_FAX));
+  rb_define_const (rb_mCairo_MimeType, "CCITT_FAX_PARAMS",
+                   rb_str_new_cstr (CAIRO_MIME_TYPE_CCITT_FAX_PARAMS));
+  rb_define_const (rb_mCairo_MimeType, "EPS",
+                   rb_str_new_cstr (CAIRO_MIME_TYPE_EPS));
+  rb_define_const (rb_mCairo_MimeType, "EPS_PARAMS",
+                   rb_str_new_cstr (CAIRO_MIME_TYPE_EPS_PARAMS));
+#endif
 
 #if CAIRO_CHECK_VERSION(1, 10, 0)
   rb_mCairo_RegionOverlap = rb_define_module_under (rb_mCairo, "RegionOverlap");
@@ -725,4 +761,29 @@ Init_cairo_constants (void)
   rb_define_const (rb_mCairo_PDFMetadata, "MOD_DATE",
                    INT2NUM (CAIRO_PDF_METADATA_MOD_DATE));
 #endif
+
+#if CAIRO_CHECK_VERSION(1, 15, 10)
+  rb_mCairo_SVGUnit =
+    rb_define_module_under (rb_mCairo, "SVGUnit");
+  rb_define_const (rb_mCairo_SVGUnit, "USER",
+                   INT2NUM (CAIRO_SVG_UNIT_USER));
+  rb_define_const (rb_mCairo_SVGUnit, "EM",
+                   INT2NUM (CAIRO_SVG_UNIT_EM));
+  rb_define_const (rb_mCairo_SVGUnit, "EX",
+                   INT2NUM (CAIRO_SVG_UNIT_EX));
+  rb_define_const (rb_mCairo_SVGUnit, "PX",
+                   INT2NUM (CAIRO_SVG_UNIT_PX));
+  rb_define_const (rb_mCairo_SVGUnit, "IN",
+                   INT2NUM (CAIRO_SVG_UNIT_IN));
+  rb_define_const (rb_mCairo_SVGUnit, "CM",
+                   INT2NUM (CAIRO_SVG_UNIT_CM));
+  rb_define_const (rb_mCairo_SVGUnit, "MM",
+                   INT2NUM (CAIRO_SVG_UNIT_MM));
+  rb_define_const (rb_mCairo_SVGUnit, "PT",
+                   INT2NUM (CAIRO_SVG_UNIT_PT));
+  rb_define_const (rb_mCairo_SVGUnit, "PC",
+                   INT2NUM (CAIRO_SVG_UNIT_PC));
+  rb_define_const (rb_mCairo_SVGUnit, "PERCENT",
+                   INT2NUM (CAIRO_SVG_UNIT_PERCENT));
+#endif
 }
