@@ -10,7 +10,9 @@ class ContextTest < Test::Unit::TestCase
     context = Cairo::Context.new(@surface)
     @surface.destroy
     assert_not_equal("%%EOF\n", @output.string[-6..-1])
+    assert {not context.destroyed?}
     context.destroy
+    assert {context.destroyed?}
     assert_equal("%%EOF\n", @output.string[-6..-1])
   end
 
@@ -120,4 +122,25 @@ class ContextTest < Test::Unit::TestCase
                    uris)
     end
   end
+
+  def test_raw_address
+    context = Cairo::Context.new(@surface)
+    assert do
+      context.raw_address > 0
+    end
+  end
+
+  def test_hairline
+    only_cairo_version(1, 17, 6)
+
+    Cairo::Context.create(@surface) do |context|
+      assert do
+        not context.hairline?
+      end
+      context.hairline = true
+      assert do
+        context.hairline?
+      end
+    end
+  end
 end
